<?php

namespace Vtbpay\Classes\Common;

(defined('ABSPATH') || PHP_SAPI == 'cli') or die('Restricted access');

use \Vtbpay\Classes\Exception\VtbPayException;

class Request
{
    public function sendRequest(
        $url,
        $data = [],
        $headers = [],
        $method = 'POST',
        $jsonEncode = true
    ) {
        $curl = curl_init();
        
        if(array_filter($headers, function ($header) {
            return stripos($header, 'Content-type: application/json') !== false;
        }) && $jsonEncode) $data = json_encode($data);

        if ($method === 'POST') {
            curl_setopt($curl, CURLOPT_POST, 1);
            curl_setopt($curl, CURLOPT_POSTFIELDS, $data);
        } 
        elseif ($method === 'PUT') {
            curl_setopt($curl, CURLOPT_CUSTOMREQUEST, 'PUT');
            curl_setopt($curl, CURLOPT_POSTFIELDS, $data);
        } 
        else {
            $url .= is_array($data) ? '?' . http_build_query($data) : '';
        }

        curl_setopt($curl, CURLOPT_URL, $url);
        curl_setopt($curl, CURLOPT_HTTPHEADER, $headers);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);

        $result = curl_exec($curl);
        
        if ($result === false) {
            throw new VtbPayException('Ошибка запроса.', [
                'curl_error' => curl_error($curl)
            ]);
        }
        
        if (empty($result)) {
            throw new VtbPayException('Запрос curl вернул пустой ответ.');
        }
        
        $decode_result = json_decode($result, true);
        
        if (json_last_error() != JSON_ERROR_NONE) {
            throw new VtbPayException('Ошибка декодирования Json.', [
                'json_last_error_msg' => json_last_error_msg(),
                'result' => $result
            ]);
        }

        curl_close($curl);

        return $decode_result;
    }
}